pub enum TimelineEventKind {
FirstSeen,
Disappeared,
Reappeared,
EvidenceChanged,
}Expand description
Timeline event category.
Variants
FirstSeen
Site was Found for the first time in the supplied scan sequence.
Disappeared
Site was Found before, then no longer Found.
Reappeared
Site was absent/not found after a previous hit, then Found again.
EvidenceChanged
Site stayed Found but normalized profile evidence changed.