pub struct ScanDiff {
pub from_scan_id: ScanId,
pub to_scan_id: ScanId,
pub added_found: Vec<CheckOutcome>,
pub removed_found: Vec<CheckOutcome>,
pub verdict_changes: Vec<VerdictChange>,
pub evidence_changes: Vec<EvidenceChange>,
}Expand description
Deterministic scan-to-scan diff used as the basis for timelines and watchlists.
Fields
from_scan_id: ScanIdPrevious scan id.
to_scan_id: ScanIdCurrent scan id.
added_found: Vec<CheckOutcome>Found accounts that were not Found in the previous scan.
removed_found: Vec<CheckOutcome>Accounts that were Found previously but are no longer Found.
verdict_changes: Vec<VerdictChange>Sites present in both scans whose verdict changed.
evidence_changes: Vec<EvidenceChange>Found sites whose normalized profile evidence changed.