pub struct TimelineEvent {
pub scan_id: ScanId,
pub at_ms: u64,
pub site: String,
pub url: String,
pub kind: TimelineEventKind,
pub before: Option<MatchKind>,
pub after: Option<MatchKind>,
pub evidence_change: Option<EvidenceChange>,
}Expand description
One lifecycle event for a profile across scans.
Fields
scan_id: ScanIdScan id where the event was observed.
at_ms: u64Scan start timestamp.
site: StringSite name.
url: StringBest URL known for the site at this point in the timeline.
kind: TimelineEventKindEvent category.
before: Option<MatchKind>Previous verdict, when known.
after: Option<MatchKind>Current verdict, when the current scan mentioned the site.
evidence_change: Option<EvidenceChange>Evidence transition for TimelineEventKind::EvidenceChanged.